# Copyright (c) 2020 safexl

from safexl.toolkit import *
import safexl.xl_constants as xl_constants
import safexl.colors as colors


__author__ = "Eric Smith"
__email__ = "ThePoetCoder@gmail.com"
__license__ = "MIT"
__version__ = "0.0.7"
